package mosaic

  1. Overview
  2. Docs

Module Mosaic_mlx.PositionSource

CSS position property controlling normal flow participation.

type t = Toffee.Style.Position.t =
  1. | Relative
    (*

    The offset is computed relative to the final position given by the layout algorithm.

    *)
  2. | Absolute
    (*

    The node is taken out of the normal flow and positioned relative to its parent.

    *)