package mosaic

  1. Overview
  2. Docs

Module Mosaic_mlx.Syntax_themeSource

Syntax themes: maps capture-group names to terminal styles.

The type for syntax themes.

Sourceval make : base:Ansi.Style.t -> (string * Ansi.Style.t) list -> t

make ~base mappings is a theme with base as the default style.

Sourceval default : t

The built-in dark theme.

Sourceval resolve_overlay : t -> string -> Ansi.Style.t

resolve_overlay theme group is the raw overlay style for group.

Sourceval resolve : t -> string -> Ansi.Style.t

resolve theme group is the complete style for group: overlay merged on top of the base style.

Sourceval apply : t -> content:string -> (int * int * string) list -> span list

apply theme ~content ranges is the list of styled spans for content under theme.