package mosaic

  1. Overview
  2. Docs

Module Box.Props

type t

The type for declarative property bundles. Used for reconciler diffing.

val make : ?border:bool -> ?border_style:Grid.Border.t -> ?border_sides:Grid.Border.side list -> ?border_color:Ansi.Color.t -> ?focused_border_color:Ansi.Color.t -> ?background:Ansi.Color.t -> ?fill:bool -> ?title:string -> ?title_alignment:[ `Left | `Center | `Right ] -> unit -> t

make () is a property set with the same defaults as create. Border-related options auto-enable borders when present.

val default : t

default is make ().

val equal : t -> t -> bool

equal a b is true iff a and b describe identical visual properties.