package mosaic

  1. Overview
  2. Docs

Module Canvas.Props

type t

The type for declarative property bundles used by the reconciler for diffing.

val make : ?respect_alpha:bool -> unit -> t

make () is a property set with the same defaults as create.

Optional parameters:

  • respect_alpha controls alpha blending within the canvas grid. Defaults to false.
val default : t

default is make ().

val equal : t -> t -> bool

equal a b is true iff a and b describe identical properties.