package mosaic

  1. Overview
  2. Docs

Module Markdown.Props

type t

The type for bundled markdown widget properties.

val make : ?content:string -> ?conceal:bool -> ?streaming:bool -> ?style:style -> unit -> t

make () is a props value. With:

  • content: the markdown source text. Defaults to "".
  • conceal: whether to hide markdown syntax characters. Defaults to true.
  • streaming: whether to enable streaming mode. Defaults to false.
  • style: the style resolver. Defaults to default_style.
val default : t

default is the default props value, equivalent to make ().

val equal : t -> t -> bool

equal a b is true iff a and b are equal.