package mosaic

  1. Overview
  2. Docs

Module Progress_bar.Props

type t

The type for declarative property bundles used for reconciler diffing.

val make : ?value:float -> ?min:float -> ?max:float -> ?orientation:orientation -> ?filled_color:Ansi.Color.t -> ?empty_color:Ansi.Color.t -> unit -> t

make () is a property set with:

  • value is the fill value. Defaults to 0.0.
  • min is the lower bound of the range. Defaults to 0.0.
  • max is the upper bound of the range. Defaults to 1.0.
  • orientation is the track direction. Defaults to `Horizontal.
  • filled_color is the color of the filled portion. Defaults to medium gray.
  • empty_color is the color of the unfilled portion. Defaults to dark gray.
val default : t

default is make ().

val equal : t -> t -> bool

equal a b is true iff a and b describe identical visual properties.