package mosaic

  1. Overview
  2. Docs

Module Scroll_bar.Props

type t

The type for the declarative property bundle used for reconciler diffing.

val make : ?orientation:orientation -> ?show_arrows:bool -> ?track_color:Ansi.Color.t -> ?thumb_color:Ansi.Color.t -> ?arrow_fg:Ansi.Color.t -> ?arrow_bg:Ansi.Color.t -> unit -> t

make () is a scroll bar property bundle. The optional parameters are:

  • orientation — layout direction. Defaults to `Vertical.
  • show_arrows — display arrow buttons at each end. Defaults to false.
  • track_color — track background color.
  • thumb_color — thumb foreground color.
  • arrow_fg — arrow foreground color. Defaults to white.
  • arrow_bg — arrow background color. Defaults to transparent.
val default : t

default is make ().

val equal : t -> t -> bool

equal a b is true iff a and b describe identical visual properties.