package mosaic

  1. Overview
  2. Docs

Module Spinner.Props

type t

The type for declarative property bundles used by the reconciler.

val make : ?frame_set:frame_set -> ?color:Ansi.Color.t -> unit -> t

make () is a property set, with:

val default : t

default is make ().

val equal : t -> t -> bool

equal a b is true iff a and b describe identical visual properties.