package mosaic

  1. Overview
  2. Docs

Module Text.Props

type t

Declarative property bundle for reconciler diffing.

val make : ?content:string -> ?text_style:Ansi.Style.t -> ?wrap:Text_surface.wrap -> ?selectable:bool -> ?selection_bg:Ansi.Color.t -> ?selection_fg:Ansi.Color.t -> ?tab_width:int -> ?truncate:bool -> unit -> t

make () is a property set with the same defaults as create.

val default : t

default is make ().

val equal : t -> t -> bool

equal a b is true iff a and b describe identical visual properties.