package mosaic

  1. Overview
  2. Docs

Module Text_input.Props

type t

The type for declarative property bundles, used by the reconciler for diffing.

val make : ?value:string -> ?cursor:int -> ?selection:(int * int) option -> ?placeholder:string -> ?max_length:int -> ?text_color:Ansi.Color.t -> ?background_color:Ansi.Color.t -> ?focused_text_color:Ansi.Color.t -> ?focused_background_color:Ansi.Color.t -> ?placeholder_color:Ansi.Color.t -> ?selection_color:Ansi.Color.t -> ?selection_fg:Ansi.Color.t -> ?cursor_style:[ `Block | `Line | `Underline ] -> ?cursor_color:Ansi.Color.t -> ?cursor_blinking:bool -> unit -> t

make () is a property set with the same defaults as create.

val default : t

default is make ().

val equal : t -> t -> bool

equal a b is true iff a and b describe identical visual properties.