package mosaic

  1. Overview
  2. Docs

Module Textarea.Props

type t

Declarative property bundle for reconciler diffing.

val make : ?value:string -> ?cursor:int -> ?selection:(int * int) option -> ?spans:Text_buffer.span list -> ?ghost_text:string -> ?ghost_text_color:Ansi.Color.t -> ?placeholder:string -> ?wrap:Text_surface.wrap -> ?text_color:Ansi.Color.t -> ?background_color:Ansi.Color.t -> ?focused_text_color:Ansi.Color.t -> ?focused_background_color:Ansi.Color.t -> ?placeholder_color:Ansi.Color.t -> ?selection_color:Ansi.Color.t -> ?selection_fg:Ansi.Color.t -> ?cursor_style:[ `Block | `Line | `Underline ] -> ?cursor_color:Ansi.Color.t -> ?cursor_blinking:bool -> unit -> t

make () is a property set with the same defaults as create.

val default : t

default is make ().

val equal : t -> t -> bool

equal a b is true iff a and b describe identical visual properties.